@@ -5,7 +5,6 @@ import contextvars
 import copy
 import dataclasses
 import itertools
-from collections import Counter
 from collections.abc import Callable
 from typing import (
     TYPE_CHECKING,
@@ -14,6 +13,7 @@ from typing import (
     cast,
 )
 
+from django.core.exceptions import FieldDoesNotExist
 from django.db import models
 from django.db.models import Prefetch
 from django.db.models.constants import LOOKUP_SEP
@@ -368,6 +368,61 @@ class OptimizerStore:
                     True,
                 )
 
+        if config.enable_only:
+            try:
+                from django.contrib.contenttypes.fields import GenericRelation
+            except (ImportError, RuntimeError):
+                GenericRelation = None  # noqa: N806
+
+            parent_model = qs.model
+            for prefetch in to_prefetch.values():
+                if isinstance(prefetch, str) or prefetch.queryset is None:  # type: ignore[reportUnnecessaryComparison]
+                    continue
+
+                inspector = PrefetchInspector(prefetch)
+                if inspector.only is None:
+                    continue
+
+                path = prefetch.prefetch_through
+                if LOOKUP_SEP in path:
+                    continue
+
+                try:
+                    relation = parent_model._meta.get_field(path)
+                except FieldDoesNotExist:
+                    relation = None
+                    for f in parent_model._meta.get_fields():
+                        if getattr(f, "related_name", None) == path:
+                            relation = f
+                            break
+                    if relation is None:
+                        continue
+
+                if isinstance(relation, (models.ManyToManyField, ManyToManyRel)):
+                    continue
+
+                if GenericRelation is not None and isinstance(
+                    relation, GenericRelation
+                ):
+                    fk_fields = frozenset({
+                        relation.object_id_field_name,
+                        relation.content_type_field_name,
+                    })
+                elif isinstance(relation, (ManyToOneRel, OneToOneRel)):
+                    fk_field = getattr(relation, "field", None)
+                    fk_attname = (
+                        getattr(fk_field, "attname", None) if fk_field else None
+                    )
+                    if fk_attname is None:
+                        continue
+                    fk_fields = frozenset({fk_attname})
+                else:
+                    continue
+
+                missing = fk_fields - inspector.only
+                if missing:
+                    inspector.only |= missing
+
         # First prefetch_related(None) to clear all existing prefetches, and then
         # add ours, which also contains them. This is to avoid the
         # "lookup was already seen with a different queryset" error
@@ -654,6 +709,10 @@ def _get_selections(
     )
 
 
+def _get_field_arguments(node: FieldNode) -> tuple:
+    return tuple(sorted(node.arguments or (), key=lambda a: a.name.value))
+
+
 def _generate_selection_resolve_info(
     info: GraphQLResolveInfo,
     field_nodes: list[FieldNode],
@@ -804,7 +863,35 @@ def _get_hints_from_django_foreign_key(
     cache: dict[type[models.Model], list[tuple[int, OptimizerStore]]],
     level: int = 0,
 ) -> OptimizerStore:
-    if _must_use_prefetch_related(config, field, model_field):
+    # First, collect hints from nested fields to check if they have annotations,
+    # which are incompatible with select_related.
+    # Annotations must be applied directly to the related model's queryset, not
+    # prefixed onto the outer queryset (which is what with_prefix does).
+    nested_stores: list[
+        tuple[StrawberryObjectDefinition, type[models.Model], OptimizerStore]
+    ] = []
+    for f_type_def in get_possible_type_definitions(field.type):
+        f_model = model_field.related_model
+        f_store = _get_model_hints(
+            f_model,
+            schema,
+            f_type_def,
+            parent_type=field_definition,
+            info=field_info,
+            config=config,
+            cache=cache,
+            level=level + 1,
+        )
+        if f_store is not None:
+            nested_stores.append((f_type_def, f_model, f_store))
+
+    # Check if any nested store has annotations.
+    # Annotations are incompatible with select_related because they need to be
+    # applied directly to the related model's queryset (via Prefetch), not
+    # prefixed onto the outer queryset.
+    has_annotations = any(f_store.annotate for _, _, f_store in nested_stores)
+
+    if _must_use_prefetch_related(config, field, model_field) or has_annotations:
         store = _get_hints_from_django_relation(
             field,
             field_selection=field_selection,
@@ -834,21 +921,9 @@ def _get_hints_from_django_foreign_key(
             f"{path}{LOOKUP_SEP}{resolve_model_field_name(remote_field)}",
         )
 
-    for f_type_def in get_possible_type_definitions(field.type):
-        f_model = model_field.related_model
-        f_store = _get_model_hints(
-            f_model,
-            schema,
-            f_type_def,
-            parent_type=field_definition,
-            info=field_info,
-            config=config,
-            cache=cache,
-            level=level + 1,
-        )
-        if f_store is not None:
-            cache.setdefault(f_model, []).append((level, f_store))
-            store |= f_store.with_prefix(path, info=field_info)
+    for _f_type_def, f_model, f_store in nested_stores:
+        cache.setdefault(f_model, []).append((level, f_store))
+        store |= f_store.with_prefix(path, info=field_info)
 
     return store
 
@@ -1026,7 +1101,41 @@ def _get_hints_from_django_field(
         return None
 
     model_fieldname: str = getattr(field, "django_name", None) or field.python_name
-    if (model_field := get_model_field(model, model_fieldname)) is None:
+    if LOOKUP_SEP in model_fieldname:
+        model_field = None
+        relation_prefix = ""
+
+        parts = model_fieldname.split(LOOKUP_SEP)
+        if not all(parts):
+            return None
+
+        current_model = model
+        relation_parts: list[str] = []
+        for index, part in enumerate(parts):
+            try:
+                current_field = get_model_field(current_model, part)
+            except FieldDoesNotExist:
+                return None
+
+            if index < len(parts) - 1:
+                if not isinstance(current_field, (models.ForeignKey, OneToOneRel)):
+                    return None
+
+                related_model = getattr(current_field, "related_model", None)
+                if related_model is None:
+                    return None
+
+                current_model = related_model
+                relation_parts.append(part)
+                continue
+
+            model_field = current_field
+            relation_prefix = LOOKUP_SEP.join(relation_parts)
+    else:
+        model_field = get_model_field(model, model_fieldname)
+        relation_prefix = ""
+
+    if model_field is None:
         return None
 
     lookup_prefix = prefix + LOOKUP_SEP if prefix else ""
@@ -1068,6 +1177,10 @@ def _get_hints_from_django_field(
         )
     else:
         store = OptimizerStore.with_hints(only=[path])
+        if relation_prefix:
+            relation_path = f"{lookup_prefix}{relation_prefix}"
+            if not any(sr.startswith(relation_path) for sr in store.select_related):
+                store.select_related.append(relation_path)
 
     return store
 
@@ -1183,12 +1296,29 @@ def _get_model_hints(
             lookup_prefix + f for f in model.polymorphic_internal_model_fields
         )
 
+    # Group selections by actual field name to detect aliases
+    selections_by_key = _get_selections(info, parent_type)
+    field_name_groups: dict[str, list[list[FieldNode]]] = {}
+    for field_nodes in selections_by_key.values():
+        name = field_nodes[0].name.value
+        field_name_groups.setdefault(name, []).append(field_nodes)
+
+    # Merge aliased selections with same arguments; skip those with different args
+    merged_node_lists: list[list[FieldNode]] = []
+    for groups in field_name_groups.values():
+        if len(groups) == 1:
+            merged_node_lists.append(groups[0])
+        else:
+            first_args = _get_field_arguments(groups[0][0])
+            if all(_get_field_arguments(g[0]) == first_args for g in groups[1:]):
+                merged_node_lists.append([node for group in groups for node in group])
+
     selections = [
         field_data
-        for f_selection in _get_selections(info, parent_type).values()
+        for f_nodes in merged_node_lists
         if (
             field_data := _get_field_data(
-                f_selection,
+                f_nodes,
                 object_definition,
                 schema,
                 parent_type=parent_type,
@@ -1197,15 +1327,8 @@ def _get_model_hints(
         )
         is not None
     ]
-    fields_counter = Counter(field_data[0] for field_data in selections)
 
     for field, f_definition, f_selection, f_info in selections:
-        # If a field is selected more than once in the query, that means it is being
-        # aliased. In this case, optimizing it would make one query to affect the other,
-        # resulting in wrong results for both.
-        if fields_counter[field] > 1:
-            continue
-
         # Add annotations from the field if they exist
         if field_store := _get_hints_from_field(field, f_info=f_info, prefix=prefix):
             store |= field_store
@@ -1250,7 +1373,7 @@ def _get_model_hints(
     # In case we skipped optimization for a relation, we might end up with a new QuerySet
     # which would not select its parent relation field on `.only()`, causing n+1 issues.
     # Make sure that in this case we also select it.
-    if level == 0 and store.only and info.path.prev:
+    if level == 0 and store.only:
         own_fk_fields = [
             field
             for field in get_model_fields(model).values()
@@ -1258,18 +1381,23 @@ def _get_model_hints(
         ]
 
         path = info.path
-        while path := path.prev:
+        while path:
+            if not path.typename:
+                path = path.prev
+                continue
+
             type_ = schema.get_type_by_name(path.typename)
             if not isinstance(type_, StrawberryObjectDefinition):
+                path = path.prev
                 continue
 
-            if not (strawberry_django_type := get_django_definition(type_.origin)):
-                continue
+            if strawberry_django_type := get_django_definition(type_.origin):
+                for field in own_fk_fields:
+                    if field.related_model is strawberry_django_type.model:
+                        store.only.append(field.attname)
+                        break
 
-            for field in own_fk_fields:
-                if field.related_model is strawberry_django_type.model:
-                    store.only.append(field.attname)
-                    break
+            path = path.prev
 
     return store
 
@@ -1324,11 +1452,24 @@ def _get_model_hints_from_connection(
             e_definition = get_object_definition(e_definition, strict=True)
         assert isinstance(e_definition, StrawberryObjectDefinition)
 
+        # Get the GraphQL definition first, then look it up in the schema
+        # to ensure we get the properly specialized/registered type
         e_gql_definition = _get_gql_definition(
             schema,
             e_definition,
         )
         assert isinstance(e_gql_definition, (GraphQLObjectType, GraphQLInterfaceType))
+
+        # For generic Edge types, we need to get the actual specialized type from the GraphQL schema
+        # Otherwise fragments defined on the concrete Edge type (e.g. UserTypeEdge) won't match
+        edge_type_name = f"{n_definition.name}Edge"
+        if edge_type_name in schema.schema_converter.type_map:
+            specialized_edge = schema.schema_converter.type_map[edge_type_name]
+            if hasattr(specialized_edge, "implementation"):
+                specialized_edge = specialized_edge.implementation
+            if isinstance(specialized_edge, (GraphQLObjectType, GraphQLInterfaceType)):
+                e_gql_definition = specialized_edge
+
         e_info = _generate_selection_resolve_info(
             info,
             edges,
