@@ -1,11 +1,12 @@
 # ruff: noqa: B904, BLE001, F811, PT012, A001
+import uuid
 from enum import Enum
 from typing import Annotated, Any, cast
 
 import pytest
 import strawberry
 from django.db.models import Case, Count, Q, QuerySet, Value, When
-from strawberry import auto
+from strawberry import Info, Some, auto
 from strawberry.exceptions import MissingArgumentsAnnotationsError
 from strawberry.relay import GlobalID
 from strawberry.types import ExecutionResult, get_object_definition
@@ -75,7 +76,7 @@ class FruitFilter:
     @strawberry_django.filter_field
     def types_number(
         self,
-        info,
+        info: Info,
         queryset: QuerySet,
         prefix,
         value: filter_types.ComparisonFilterLookup[int],
@@ -103,7 +104,7 @@ class FruitFilter:
         return queryset.union(queryset, all=True), Q()
 
     @strawberry_django.filter_field
-    def filter(self, info, queryset: QuerySet, prefix):
+    def filter(self, info: Info, queryset: QuerySet, prefix):
         return process_filters(
             cast("WithStrawberryObjectDefinition", self),
             queryset.filter(~Q(**{f"{prefix}name": "DARK_BERRY"})),
@@ -113,11 +114,23 @@ class FruitFilter:
         )
 
 
+@strawberry_django.filter_type(models.UUIDModel, lookups=True)
+class UUIDModelFilter:
+    id: auto
+
+
+@strawberry_django.type(models.UUIDModel, filters=UUIDModelFilter)
+class UUIDModelType:
+    id: auto
+    text: auto
+
+
 @strawberry.type
 class Query:
     types: list[FruitType] = strawberry_django.field(filters=FruitTypeFilter)
     fruits: list[Fruit] = strawberry_django.field(filters=FruitFilter)
     vegetables: list[Vegetable] = strawberry_django.field(filters=VegetableFilter)
+    items: list[UUIDModelType] = strawberry_django.field()
 
 
 @pytest.fixture
@@ -128,6 +141,7 @@ def query():
 @pytest.mark.parametrize(
     ("value", "resolved"),
     [
+        (None, None),
         (2, 2),
         ("something", "something"),
         (GlobalID("", "24"), "24"),
@@ -136,6 +150,18 @@ def query():
             [1, "str", GlobalID("", "24"), Version.THREE],
             [1, "str", "24", Version.THREE.value],
         ),
+        # Some (inner type of Maybe) tests
+        (Some("test_string"), "test_string"),
+        (Some(None), None),
+        (Some(Version.TWO), Version.TWO.value),
+        (Some(GlobalID("FruitNode", "42")), "42"),
+        (Some(Some("nested")), "nested"),
+        (Some(Some(None)), None),
+        (
+            [Some(1), Some("test"), Some(None), Some(Version.ONE)],
+            [1, "test", None, Version.ONE.value],
+        ),
+        ([Some(Some("foo")), Some(None)], ["foo", None]),
     ],
 )
 def test_resolve_value(value, resolved):
@@ -177,7 +203,7 @@ def test_filter_field():
     try:
 
         @strawberry_django.filter_field
-        def field_method(self, root, info, prefix, value: str, queryset):
+        def field_method(self, root, info: Info, prefix, value: str, queryset):
             pass
 
     except Exception as exc:
@@ -243,7 +269,7 @@ def test_filter_field_on_object():
     try:
 
         @strawberry_django.filter_field
-        def filter(self, root, info, prefix, queryset):
+        def filter(self, root, info: Info, prefix, queryset):
             pass
 
     except Exception as exc:
@@ -254,7 +280,7 @@ def test_filter_field_method():
     @strawberry_django.filter_type(models.Fruit)
     class Filter:
         @strawberry_django.order_field
-        def custom_filter(self, root, info, prefix, value: auto, queryset):
+        def custom_filter(self, root, info: Info, prefix, value: auto, queryset):
             assert self == filter_, "Unexpected self passed"
             assert root == filter_, "Unexpected root passed"
             assert info == fake_info, "Unexpected info passed"
@@ -279,7 +305,7 @@ def test_filter_object_method():
             raise AssertionError("Never called due to object filter override")
 
         @strawberry_django.filter_field
-        def filter(self, root, info, prefix, queryset):
+        def filter(self, root, info: Info, prefix, queryset):
             assert self == filter_, "Unexpected self passed"
             assert root == filter_, "Unexpected root passed"
             assert info == fake_info, "Unexpected info passed"
@@ -578,3 +604,198 @@ async def test_async_resolver_filter(fruits):
     assert result.data["fruits"] == [
         {"name": "strawberry"},
     ]
+
+
+def test_resolve_value_some_with_range_lookup():
+    range_lookup = strawberry_django.RangeLookup(
+        start=Some(GlobalID("FruitNode", "10")),
+        end=Some(GlobalID("FruitNode", "20")),
+    )
+    assert resolve_value(range_lookup.start) == "10"
+    assert resolve_value(range_lookup.end) == "20"
+
+
+def test_resolve_value_some_with_comparison_filter_lookup():
+    gid = GlobalID("FruitNode", "125")
+    filter_lookup = strawberry_django.ComparisonFilterLookup(
+        exact=Some(gid),
+        range=strawberry_django.RangeLookup(start=Some(gid), end=Some(gid)),
+    )
+
+    @strawberry_django.filters.filter_type(models.Fruit)
+    class Filter:
+        id: strawberry_django.ComparisonFilterLookup[GlobalID] | None
+
+    filter_: Any = Filter(id=filter_lookup)  # type: ignore[arg-type]
+    object_: Any = object()
+    q = process_filters(filter_, object_, object_)[1]
+    assert q == Q(id__exact="125", id__range=["125", "125"])
+
+
+def test_filter_method_some_value_resolution():
+    received_values: dict[str, Any] = {}
+
+    @strawberry_django.filters.filter_type(models.Fruit)
+    class Filter:
+        @strawberry_django.filter_field(resolve_value=True)
+        def field_filter_resolved(self, value: GlobalID, prefix):
+            received_values["resolved"] = value
+            return Q()
+
+        @strawberry_django.filter_field
+        def field_filter_unset(self, value: GlobalID, prefix):
+            received_values["unset"] = value
+            return Q()
+
+    gid = GlobalID("FruitNode", "125")
+    filter_: Any = Filter(
+        field_filter_resolved=Some(gid),  # type: ignore[arg-type]
+        field_filter_unset=Some(gid),  # type: ignore[arg-type]
+    )
+    object_: Any = object()
+    process_filters(filter_, object_, object_)
+
+    assert isinstance(received_values["resolved"], str)
+    assert received_values["resolved"] == "125"
+    # When resolve_value is UNSET for filter methods, Some wrapper is kept
+    assert isinstance(received_values["unset"], Some)
+    assert received_values["unset"].value == gid
+
+
+def test_filter_with_some_enum_value():
+    filter_lookup = strawberry_django.ComparisonFilterLookup(
+        exact=Some(Version.TWO),
+    )
+    assert resolve_value(filter_lookup.exact) == "second"
+
+
+def test_filter_with_some_in_list():
+    filter_lookup = strawberry_django.BaseFilterLookup(
+        in_list=[Some(GlobalID("FruitNode", "1")), Some(GlobalID("FruitNode", "2"))],
+    )
+    resolved = resolve_value(filter_lookup.in_list)
+    assert resolved == ["1", "2"]
+
+
+def test_filter_with_nested_some():
+    nested = Some(Some(Some(GlobalID("FruitNode", "42"))))
+    assert resolve_value(nested) == "42"
+
+
+def test_filter_with_some_none():
+    assert resolve_value(Some(None)) is None
+    assert resolve_value(Some(Some(None))) is None
+
+
+def test_process_filters_with_some_wrapped_values():
+    @strawberry_django.filters.filter_type(models.Fruit)
+    class Filter:
+        name: strawberry_django.StrFilterLookup | None
+
+    name_lookup = strawberry_django.StrFilterLookup(
+        exact=Some("strawberry"),
+        contains=Some("berry"),  # type: ignore[arg-type]
+    )
+    filter_: Any = Filter(name=name_lookup)
+    object_: Any = object()
+    _, q = process_filters(filter_, object_, object_)
+    assert set(q.children) == {
+        ("name__exact", "strawberry"),
+        ("name__contains", "berry"),
+    }
+
+
+def test_process_filters_with_some_global_id_in_lookup():
+    @strawberry_django.filters.filter_type(models.Fruit)
+    class Filter:
+        id: strawberry_django.BaseFilterLookup[GlobalID] | None
+
+    id_lookup = strawberry_django.BaseFilterLookup(
+        exact=Some(GlobalID("FruitNode", "42")),
+        in_list=[
+            Some(GlobalID("FruitNode", "1")),
+            Some(GlobalID("FruitNode", "2")),
+        ],
+    )
+    filter_: Any = Filter(id=id_lookup)  # type: ignore[arg-type]
+    object_: Any = object()
+    _, q = process_filters(filter_, object_, object_)
+    assert dict(q.children) == {"id__exact": "42", "id__in": ["1", "2"]}
+
+
+@pytest.mark.django_db
+@pytest.mark.parametrize(
+    ("lookup_name", "value_getter"),
+    [
+        ("exact", lambda u: f'"{u}"'),
+        ("iExact", lambda u: f'"{u}"'),
+        ("inList", lambda u: f'["{u}"]'),
+        ("contains", lambda u: f'"{u[5:10]}"'),
+        ("iContains", lambda u: f'"{u[5:10].upper()}"'),
+        ("startsWith", lambda u: f'"{u[:5]}"'),
+        ("iStartsWith", lambda u: f'"{u[:5].upper()}"'),
+        ("endsWith", lambda u: f'"{u[-5:]}"'),
+        ("iEndsWith", lambda u: f'"{u[-5:].upper()}"'),
+        ("regex", lambda u: f'"{u[:5]}.*"'),
+        ("iRegex", lambda u: f'"{u[:5].upper()}.*"'),
+    ],
+)
+def test_uuid_lookup_string_filters(query, lookup_name, value_getter):
+    """Test that UUID fields support string-based partial lookups and exact matches.
+
+    Verifies that lookups like contains, startsWith, regex, etc., accept string inputs
+    and correctly filter UUIDs, in addition to standard exact/inList matches.
+    """
+    instance = models.UUIDModel.objects.create(text="test")
+    uuid_str = str(instance.id)
+    filter_value = value_getter(uuid_str)
+
+    result = query(f"""
+        query {{
+            items(filters: {{ id: {{ {lookup_name}: {filter_value} }} }}) {{
+                id
+                text
+            }}
+        }}
+    """)
+
+    assert not result.errors
+    assert len(result.data["items"]) == 1
+    assert result.data["items"][0]["id"] == uuid_str
+
+
+def test_filterlookup_str_emits_warning():
+    with pytest.warns(UserWarning, match="FilterLookup\\[str\\].*Use StrFilterLookup"):
+        filter_types.FilterLookup[str]
+
+
+def test_filterlookup_uuid_emits_warning():
+    with pytest.warns(UserWarning, match="FilterLookup\\[UUID\\].*Use StrFilterLookup"):
+        filter_types.FilterLookup[uuid.UUID]
+
+
+def test_skip_filter_field():
+    @strawberry_django.filter_type(models.Fruit)
+    class Filter:
+        name: auto
+        min_similarity: float | None = strawberry_django.filter_field(
+            default=0.3, skip_queryset_filter=True
+        )
+
+        @strawberry_django.filter_field
+        def filter(self, queryset: QuerySet, prefix: str):
+            if self.min_similarity is not None:
+                return queryset, Q(**{f"{prefix}name": self.min_similarity})
+            return queryset, Q()
+
+    filter_: Any = Filter(name="apple", min_similarity=0.5)
+    qs: Any = object()
+    fake_info: Any = object()
+
+    # Object-level filter method can access self.min_similarity
+    _, q = process_filters(filter_, qs, fake_info)
+    assert Q(name=0.5) == q
+
+    # Field-iteration path: min_similarity is skipped, only name produces a Q
+    _, q = process_filters(filter_, qs, fake_info, skip_object_filter_method=True)
+    assert Q(name="apple") == q
