@@ -1,3 +1,4 @@
+import django
 from django.db import models
 
 
@@ -27,8 +28,17 @@ class Project(models.Model):
     class Meta:
         constraints = (
             models.CheckConstraint(
-                check=(models.Q(artist="") | models.Q(supervisor=""))
-                & (~models.Q(topic="") | ~models.Q(topic="")),
+                **(
+                    {  # type: ignore[arg-type]
+                        "condition": (models.Q(artist="") | models.Q(supervisor=""))
+                        & (~models.Q(topic="") | ~models.Q(topic=""))
+                    }
+                    if django.VERSION >= (5, 1)
+                    else {
+                        "check": (models.Q(artist="") | models.Q(supervisor=""))
+                        & (~models.Q(topic="") | ~models.Q(topic=""))
+                    }
+                ),
                 name="artist_xor_supervisor",
             ),
         )
