@@ -8,7 +8,7 @@ from django.utils.translation import gettext_lazy as _
 from django_choices_field import TextChoicesField
 
 from strawberry_django.descriptors import model_property
-from strawberry_django.optimizer import OptimizerStore, optimize
+from strawberry_django.optimizer import optimize
 from strawberry_django.utils.typing import UserType
 
 if TYPE_CHECKING:
@@ -69,7 +69,6 @@ class Project(NamedModel):
             queryset=optimize(
                 Milestone.objects.all(),
                 info,
-                store=OptimizerStore.with_hints(only="project_id"),
             ),
             to_attr="custom_milestones_property",
         )
@@ -256,3 +255,33 @@ class Quiz(models.Model):
             if max_ is not None:
                 self.sequence = max_ + 1
         super().save(*args, **kwargs)
+
+
+class Role(NamedModel):
+    """Role model for testing field_name traversal."""
+
+    id = models.BigAutoField(
+        verbose_name="ID",
+        primary_key=True,
+    )
+    description = models.TextField(blank=True, default="")
+
+
+class UserAssignedRole(models.Model):
+    """Intermediate model for testing field_name traversal with OneToOne."""
+
+    id = models.BigAutoField(
+        verbose_name="ID",
+        primary_key=True,
+    )
+    role = models.ForeignKey(
+        Role,
+        on_delete=models.CASCADE,
+        related_name="user_assignments",
+    )
+    user = models.OneToOneField(
+        User,
+        related_name="assigned_role",
+        on_delete=models.CASCADE,
+    )
+    assigned_at = models.DateTimeField(auto_now_add=True)
