@@ -32,7 +32,6 @@ from strawberry_django.fields.types import ListInput, NodeInput, NodeInputPartia
 from strawberry_django.mutations import resolvers
 from strawberry_django.optimizer import (
     DjangoOptimizerExtension,
-    OptimizerStore,
     optimize,
 )
 from strawberry_django.pagination import OffsetPaginated
@@ -55,7 +54,9 @@ from .models import (
     NamedModel,
     Project,
     Quiz,
+    Role,
     Tag,
+    UserAssignedRole,
 )
 
 UserModel = get_user_model()
@@ -78,6 +79,21 @@ class UserType(relay.Node):
     def full_name(self, root: AbstractUser) -> str:
         return f"{root.first_name or ''} {root.last_name or ''}".strip()
 
+    # Test field_name with double-underscore traversal
+    role: Optional["RoleType"] = strawberry_django.field(
+        field_name="assigned_role__role",
+    )
+
+    # Test field_name traversal to scalar field
+    role_name: str | None = strawberry_django.field(
+        field_name="assigned_role__role__name",
+    )
+
+    # Test field_name traversal to another scalar
+    role_description: str | None = strawberry_django.field(
+        field_name="assigned_role__role__description",
+    )
+
 
 @strawberry_django.type(UserModel)
 class StaffType(relay.Node):
@@ -136,7 +152,6 @@ class ProjectType(relay.Node, Named):
             queryset=optimize(
                 Milestone.objects.all(),
                 info,
-                store=OptimizerStore.with_hints(only="project_id"),
             ),
             to_attr="custom_milestones",
         )
@@ -318,7 +333,8 @@ class TagType(relay.Node, Named):
     def issues_with_selected_related_milestone_and_project(self) -> list[IssueType]:
         # here, the `select_related` is on the queryset directly, and not on the field
         return (
-            self.issues.all()  # type: ignore
+            self.issues
+            .all()  # type: ignore
             .select_related("milestone", "milestone__project")
             .order_by("id")
         )
@@ -339,6 +355,21 @@ class QuizType(relay.Node):
         return queryset.order_by("title")
 
 
+@strawberry_django.type(Role)
+class RoleType(relay.Node, Named):
+    """Role type for testing field_name traversal."""
+
+    description: strawberry.auto
+
+
+@strawberry_django.type(UserAssignedRole)
+class UserAssignedRoleType(relay.Node):
+    """UserAssignedRole type for testing field_name traversal."""
+
+    role: RoleType
+    user: UserType
+
+
 @strawberry_django.partial(Tag)
 class TagInputPartial(NodeInputPartial):
     name: strawberry.auto
@@ -448,6 +479,8 @@ class Query:
     staff: StaffType | None = strawberry_django.node()
     staff_list: list[StaffType | None] = strawberry_django.node()
 
+    user_list: list[UserType] = strawberry_django.field()
+
     issue_list: list[IssueType] = strawberry_django.field()
     issues_paginated: OffsetPaginated[IssueType] = strawberry_django.offset_paginated()
     milestone_list: list[MilestoneType] = strawberry_django.field(
@@ -463,10 +496,7 @@ class Query:
 
     favorite_conn: DjangoListConnection[FavoriteType] = strawberry_django.connection()
     issue_conn: DjangoListConnection[
-        strawberry.LazyType[
-            "IssueType",
-            "tests.projects.schema",  # type: ignore  # noqa: F821
-        ]
+        Annotated["IssueType", strawberry.lazy("tests.projects.schema")]
     ] = strawberry_django.connection()
     milestone_conn: DjangoListConnection[MilestoneType] = strawberry_django.connection()
 
