@@ -1,4 +1,5 @@
 import datetime
+import operator
 from typing import Any, cast
 
 import pytest
@@ -7,12 +8,15 @@ from django.db import DEFAULT_DB_ALIAS, connections
 from django.db.models import Prefetch
 from django.test.utils import CaptureQueriesContext
 from django.utils import timezone
+from graphql import GraphQLResolveInfo
 from pytest_mock import MockerFixture
 from strawberry.relay import GlobalID, to_base64
-from strawberry.types import ExecutionResult, get_object_definition
+from strawberry.types import ExecutionResult, Info, get_object_definition
 
 import strawberry_django
-from strawberry_django.optimizer import DjangoOptimizerExtension
+from strawberry_django.optimizer import (
+    DjangoOptimizerExtension,
+)
 from tests.projects.schema import IssueType, MilestoneType, ProjectType, StaffType
 
 from . import utils
@@ -884,7 +888,7 @@ def test_user_query_with_prefetch():
                 ),
             ],
         )
-        def custom_field(self, info) -> str:
+        def custom_field(self, info: Info) -> str:
             if hasattr(self, "prefetched_milestones"):
                 return "prefetched"
             return "not prefetched"
@@ -1109,12 +1113,93 @@ def test_query_nested_connection_with_filter_and_alias(
     assert {edge["node"]["id"] for edge in result["barIssues"]["edges"]} == bar_expected
 
 
+@pytest.mark.django_db(transaction=True)
+def test_query_prefetch_with_aliases_same_field(db, gql_client: GraphQLTestClient):
+    query = """
+      query TestQuery ($node_id: ID!) {
+        project (id: $node_id) {
+          id
+          a: milestones {
+            id
+            name
+          }
+          b: milestones {
+            id
+            name
+          }
+        }
+      }
+    """
+
+    project = ProjectFactory.create()
+    milestones = MilestoneFactory.create_batch(3, project=project)
+
+    expected_milestones = [
+        {
+            "id": to_base64("MilestoneType", m.id),
+            "name": m.name,
+        }
+        for m in milestones
+    ]
+
+    node_id = to_base64("ProjectType", project.pk)
+
+    with assert_num_queries(2 if DjangoOptimizerExtension.enabled.get() else 3):
+        res = gql_client.query(query, {"node_id": node_id})
+
+    assert res.data == {
+        "project": {
+            "id": node_id,
+            "a": expected_milestones,
+            "b": expected_milestones,
+        },
+    }
+
+
+@pytest.mark.django_db(transaction=True)
+def test_query_prefetch_with_aliases_different_subselections(
+    db, gql_client: GraphQLTestClient
+):
+    query = """
+      query TestQuery ($node_id: ID!) {
+        project (id: $node_id) {
+          id
+          a: milestones {
+            id
+          }
+          b: milestones {
+            id
+            name
+          }
+        }
+      }
+    """
+
+    project = ProjectFactory.create()
+    milestones = MilestoneFactory.create_batch(3, project=project)
+    node_id = to_base64("ProjectType", project.pk)
+
+    with assert_num_queries(2 if DjangoOptimizerExtension.enabled.get() else 3):
+        res = gql_client.query(query, {"node_id": node_id})
+
+    assert res.data == {
+        "project": {
+            "id": node_id,
+            "a": [{"id": to_base64("MilestoneType", m.id)} for m in milestones],
+            "b": [
+                {"id": to_base64("MilestoneType", m.id), "name": m.name}
+                for m in milestones
+            ],
+        },
+    }
+
+
 @pytest.mark.django_db(transaction=True)
 def test_query_with_optimizer_paginated_prefetch():
     @strawberry_django.type(Milestone, pagination=True)
     class MilestoneTypeWithNestedPrefetch:
         @strawberry_django.field()
-        def name(self, info) -> str:
+        def name(self, info: Info) -> str:
             return self.name
 
     @strawberry_django.type(
@@ -1122,7 +1207,7 @@ def test_query_with_optimizer_paginated_prefetch():
     )
     class ProjectTypeWithPrefetch:
         @strawberry_django.field()
-        def name(self, info) -> str:
+        def name(self, info: Info) -> str:
             return self.name
 
         milestones: list[MilestoneTypeWithNestedPrefetch]
@@ -2067,6 +2152,46 @@ def test_custom_prefetch_optimization_model_property_nested(gql_client):
     }
 
 
+@pytest.mark.django_db(transaction=True)
+@pytest.mark.parametrize("gql_client", ["async", "sync"], indirect=True)
+def test_custom_prefetch_optimize_auto_selects_fk(gql_client):
+    """Regression test for #862: optimize() inside Prefetch auto-adds FK field to .only()."""
+    project = ProjectFactory.create()
+    milestone = MilestoneFactory.create(project=project, name="Hello")
+
+    query = """\
+      query TestQuery {
+        projectList {
+          customMilestones {
+            id
+            name
+          }
+        }
+      }
+    """
+
+    with assert_num_queries(2) as ctx:
+        res = gql_client.query(query, assert_no_errors=False)
+    assert res.errors is None
+
+    milestone_id = str(
+        GlobalID(
+            get_object_definition(MilestoneType, strict=True).name, str(milestone.id)
+        )
+    )
+    assert res.data == {
+        "projectList": [
+            {"customMilestones": [{"id": milestone_id, "name": milestone.name}]}
+        ]
+    }
+
+    prefetch_sql = next(
+        q["sql"] for q in ctx.captured_queries if Milestone._meta.db_table in q["sql"]
+    )
+    assert "project_id" in prefetch_sql
+    assert Milestone._meta.get_field("due_date").name not in prefetch_sql
+
+
 @pytest.mark.django_db(transaction=True)
 @pytest.mark.parametrize("gql_client", ["async", "sync"], indirect=True)
 def test_correct_annotation_info(gql_client):
@@ -2201,3 +2326,643 @@ def test_mixed_annotation_prefetch(gql_client):
             ],
         }
     }
+
+
+@pytest.mark.django_db(transaction=True)
+@pytest.mark.parametrize("gql_client", ["sync", "async"], indirect=True)
+def test_nested_annotation_via_select_related(db, gql_client: GraphQLTestClient):
+    """Test that annotations work on nested types accessed via select_related.
+
+    Regression test for https://github.com/strawberry-graphql/strawberry-django/issues/549
+    and https://github.com/strawberry-graphql/strawberry-django/issues/743
+
+    When querying a nested type (e.g., issue.milestone.project) via select_related,
+    annotations on the nested type should work correctly. Previously, the optimizer
+    would try to annotate the outer queryset with a prefixed path (e.g.,
+    `milestone__project__annotation`), but this doesn't populate the annotation on
+    the nested object - it populates it on the root object.
+    """
+    from django.db.models.functions import Upper
+
+    @strawberry_django.type(Project)
+    class ProjectTypeWithAnnotation:
+        name: strawberry.auto
+        name_upper: str = strawberry_django.field(
+            annotate=Upper("name"),
+        )
+
+    @strawberry_django.type(Milestone)
+    class MilestoneTypeWithAnnotation:
+        name: strawberry.auto
+        project: ProjectTypeWithAnnotation
+
+    @strawberry_django.type(Issue)
+    class IssueTypeWithAnnotation:
+        name: strawberry.auto
+        milestone: MilestoneTypeWithAnnotation
+
+    @strawberry.type
+    class Query:
+        issues: list[IssueTypeWithAnnotation] = strawberry_django.field()
+
+    schema = strawberry.Schema(
+        query=Query,
+        extensions=[DjangoOptimizerExtension],
+    )
+
+    project = ProjectFactory.create(name="TestProject")
+    milestone = MilestoneFactory.create(project=project, name="Milestone1")
+    IssueFactory.create(milestone=milestone, name="Issue1")
+
+    query = """\
+      query TestQuery {
+        issues {
+          name
+          milestone {
+            name
+            project {
+              name
+              nameUpper
+            }
+          }
+        }
+      }
+    """
+
+    result = schema.execute_sync(query)
+    assert result.errors is None, result.errors
+    assert result.data == {
+        "issues": [
+            {
+                "name": "Issue1",
+                "milestone": {
+                    "name": "Milestone1",
+                    "project": {
+                        "name": "TestProject",
+                        "nameUpper": "TESTPROJECT",
+                    },
+                },
+            },
+        ],
+    }
+
+
+@pytest.mark.django_db(transaction=True)
+def test_annotation_on_type_via_immediate_fk(db):
+    """Test that annotations work on types accessed via an immediate FK (1-level deep).
+
+    Regression test for https://github.com/strawberry-graphql/strawberry-django/issues/869
+
+    When querying a nested type via FK (e.g., milestone.project) where the nested type
+    has an annotated field, the optimizer should use prefetch_related instead of
+    select_related so the annotation is applied to the related model's queryset.
+    """
+    from django.db.models import Count
+
+    @strawberry_django.type(Project)
+    class ProjectTypeWithAnnotation:
+        name: strawberry.auto
+        milestone_count: int = strawberry_django.field(
+            annotate=Count("milestone"),
+        )
+
+    @strawberry_django.type(Milestone)
+    class MilestoneTypeWithAnnotation:
+        name: strawberry.auto
+        project: ProjectTypeWithAnnotation
+
+    @strawberry.type
+    class Query:
+        milestones: list[MilestoneTypeWithAnnotation] = strawberry_django.field()
+
+    schema = strawberry.Schema(
+        query=Query,
+        extensions=[DjangoOptimizerExtension],
+    )
+
+    project = ProjectFactory.create(name="TestProject")
+    MilestoneFactory.create(project=project, name="M1")
+    MilestoneFactory.create(project=project, name="M2")
+
+    query = """\
+      query TestQuery {
+        milestones {
+          name
+          project {
+            name
+            milestoneCount
+          }
+        }
+      }
+    """
+
+    result = schema.execute_sync(query)
+    assert result.errors is None, result.errors
+    assert result.data is not None
+    milestones = sorted(result.data["milestones"], key=operator.itemgetter("name"))
+    assert milestones == [
+        {
+            "name": "M1",
+            "project": {
+                "name": "TestProject",
+                "milestoneCount": 2,
+            },
+        },
+        {
+            "name": "M2",
+            "project": {
+                "name": "TestProject",
+                "milestoneCount": 2,
+            },
+        },
+    ]
+
+
+@pytest.mark.django_db(transaction=True)
+def test_annotation_on_type_via_immediate_fk_dict_style(db):
+    """Test dict-style annotate on type accessed via FK (1-level deep).
+
+    Regression test for https://github.com/strawberry-graphql/strawberry-django/issues/869
+
+    Uses annotate={"key": expr} format (as reported in the issue) instead of
+    annotate=expr shorthand.
+    """
+    from django.db.models import Count
+
+    @strawberry_django.type(Milestone)
+    class MilestoneTypeWithAnnotation:
+        name: strawberry.auto
+        issue_count: int = strawberry_django.field(
+            annotate={"issue_count": Count("issue")},
+        )
+
+    @strawberry_django.type(Issue)
+    class IssueTypeWithAnnotation:
+        name: strawberry.auto
+        milestone: MilestoneTypeWithAnnotation
+
+    @strawberry.type
+    class Query:
+        issues: list[IssueTypeWithAnnotation] = strawberry_django.field()
+
+    schema = strawberry.Schema(
+        query=Query,
+        extensions=[DjangoOptimizerExtension],
+    )
+
+    project = ProjectFactory.create(name="TestProject")
+    milestone = MilestoneFactory.create(project=project, name="Milestone1")
+    IssueFactory.create(milestone=milestone, name="Issue1")
+    IssueFactory.create(milestone=milestone, name="Issue2")
+
+    query = """\
+      query TestQuery {
+        issues {
+          name
+          milestone {
+            name
+            issueCount
+          }
+        }
+      }
+    """
+
+    result = schema.execute_sync(query)
+    assert result.errors is None, result.errors
+    assert result.data is not None
+    issues = sorted(result.data["issues"], key=operator.itemgetter("name"))
+    assert issues == [
+        {
+            "name": "Issue1",
+            "milestone": {
+                "name": "Milestone1",
+                "issueCount": 2,
+            },
+        },
+        {
+            "name": "Issue2",
+            "milestone": {
+                "name": "Milestone1",
+                "issueCount": 2,
+            },
+        },
+    ]
+
+
+@pytest.mark.django_db(transaction=True)
+def test_annotation_on_type_via_reverse_one_to_one(db):
+    """Test annotations on type accessed via reverse OneToOne.
+
+    Regression test for https://github.com/strawberry-graphql/strawberry-django/issues/869
+
+    When querying User → assigned_role (reverse OneToOne) where
+    UserAssignedRoleType has an annotation, the optimizer should use
+    prefetch_related instead of select_related.
+    """
+    from django.contrib.auth import get_user_model
+    from django.db.models import Value
+    from django.db.models.functions import Upper
+
+    from tests.projects.models import Role, UserAssignedRole
+
+    @strawberry_django.type(UserAssignedRole)
+    class UserAssignedRoleTypeWithAnnotation:
+        role_name_upper: str = strawberry_django.field(
+            annotate=Upper(Value("ADMIN")),
+        )
+
+    @strawberry_django.type(get_user_model())
+    class UserTypeWithAssignedRole:
+        username: strawberry.auto
+        assigned_role: UserAssignedRoleTypeWithAnnotation | None
+
+    @strawberry.type
+    class Query:
+        users: list[UserTypeWithAssignedRole] = strawberry_django.field()
+
+    schema = strawberry.Schema(
+        query=Query,
+        extensions=[DjangoOptimizerExtension],
+    )
+
+    user = UserFactory.create(username="testuser")
+    role = Role.objects.create(name="Admin")
+    UserAssignedRole.objects.create(user=user, role=role)
+
+    query = """\
+      query TestQuery {
+        users {
+          username
+          assignedRole {
+            roleNameUpper
+          }
+        }
+      }
+    """
+
+    result = schema.execute_sync(query)
+    assert result.errors is None, result.errors
+    assert result.data is not None
+    users = [u for u in result.data["users"] if u["username"] == "testuser"]
+    assert len(users) == 1
+    assert users[0] == {
+        "username": "testuser",
+        "assignedRole": {
+            "roleNameUpper": "ADMIN",
+        },
+    }
+
+
+@pytest.mark.django_db(transaction=True)
+@pytest.mark.parametrize("gql_client", ["sync"], indirect=True)
+def test_prefetch_related_without_explicit_ordering(db, gql_client: GraphQLTestClient):
+    """Test that prefetch_related works correctly without explicit ordering.
+
+    Regression test for https://github.com/strawberry-graphql/strawberry-django/issues/772
+
+    When using prefetch_related with a custom queryset that has no explicit ordering,
+    the deterministic ordering added by get_queryset should not break the prefetch cache.
+
+    This uses to_attr which is the recommended approach.
+    """
+
+    @strawberry_django.type(Milestone)
+    class MilestoneTypeTest:
+        name: strawberry.auto
+
+    @strawberry_django.type(Project)
+    class ProjectTypeTest:
+        name: strawberry.auto
+
+        @strawberry_django.field(
+            prefetch_related=[
+                Prefetch(
+                    "milestones",
+                    queryset=Milestone.objects.filter(name__startswith="Test"),
+                    to_attr="_filtered_milestones",
+                )
+            ]
+        )
+        def filtered_milestones(self) -> list[MilestoneTypeTest]:
+            return self._filtered_milestones  # type: ignore
+
+    @strawberry.type
+    class Query:
+        projects: list[ProjectTypeTest] = strawberry_django.field()
+
+    schema = strawberry.Schema(
+        query=Query,
+        extensions=[DjangoOptimizerExtension],
+    )
+
+    # Create test data
+    project1 = ProjectFactory.create(name="Project1")
+    project2 = ProjectFactory.create(name="Project2")
+    MilestoneFactory.create(project=project1, name="TestMilestone1")
+    MilestoneFactory.create(project=project1, name="TestMilestone2")
+    MilestoneFactory.create(
+        project=project1, name="OtherMilestone"
+    )  # Should be filtered out
+    MilestoneFactory.create(project=project2, name="TestMilestone3")
+
+    query = """\
+      query TestQuery {
+        projects {
+          name
+          filteredMilestones {
+            name
+          }
+        }
+      }
+    """
+
+    # This should not cause N+1 queries
+    # Expected: 1 query for projects + 1 query for prefetched milestones = 2 queries
+    if DjangoOptimizerExtension.enabled.get():
+        with assert_num_queries(2):
+            result = schema.execute_sync(query)
+    else:
+        result = schema.execute_sync(query)
+
+    assert result.errors is None, result.errors
+    assert result.data is not None
+    # Verify the data is correct
+    projects_data = sorted(result.data["projects"], key=operator.itemgetter("name"))
+    assert len(projects_data) == 2
+    assert projects_data[0]["name"] == "Project1"
+    assert len(projects_data[0]["filteredMilestones"]) == 2
+    assert projects_data[1]["name"] == "Project2"
+    assert len(projects_data[1]["filteredMilestones"]) == 1
+
+
+@pytest.mark.django_db(transaction=True)
+@pytest.mark.parametrize("gql_client", ["sync"], indirect=True)
+def test_prefetch_related_without_to_attr(db, gql_client: GraphQLTestClient):
+    """Test that prefetch_related works correctly without to_attr.
+
+    Additional regression test for https://github.com/strawberry-graphql/strawberry-django/issues/772
+
+    When using prefetch_related without to_attr, accessing the related manager
+    should still use the prefetch cache.
+    """
+
+    @strawberry_django.type(Milestone)
+    class MilestoneTypeTest:
+        name: strawberry.auto
+
+    @strawberry_django.type(Project)
+    class ProjectTypeTest:
+        name: strawberry.auto
+
+        # Using prefetch_related without to_attr
+        @strawberry_django.field(
+            prefetch_related=[
+                Prefetch(
+                    "milestones",
+                    queryset=Milestone.objects.filter(name__startswith="Test"),
+                )
+            ]
+        )
+        def filtered_milestones(self) -> list[MilestoneTypeTest]:
+            # This should use the prefetch cache, not trigger a new query
+            return list(self.milestones.all())  # type: ignore
+
+    @strawberry.type
+    class Query:
+        projects: list[ProjectTypeTest] = strawberry_django.field()
+
+    schema = strawberry.Schema(
+        query=Query,
+        extensions=[DjangoOptimizerExtension],
+    )
+
+    # Create test data
+    project1 = ProjectFactory.create(name="Project1")
+    project2 = ProjectFactory.create(name="Project2")
+    MilestoneFactory.create(project=project1, name="TestMilestone1")
+    MilestoneFactory.create(project=project1, name="TestMilestone2")
+    MilestoneFactory.create(
+        project=project1, name="OtherMilestone"
+    )  # Won't be prefetched due to filter
+    MilestoneFactory.create(project=project2, name="TestMilestone3")
+
+    query = """\
+      query TestQuery {
+        projects {
+          name
+          filteredMilestones {
+            name
+          }
+        }
+      }
+    """
+
+    # Without to_attr, calling .all() might not use the prefetch cache
+    # This test may fail, showing the N+1 issue
+    if DjangoOptimizerExtension.enabled.get():
+        with assert_num_queries(2):
+            result = schema.execute_sync(query)
+    else:
+        result = schema.execute_sync(query)
+
+    assert result.errors is None, result.errors
+
+
+@pytest.mark.django_db(transaction=True)
+@pytest.mark.parametrize("gql_client", ["sync"], indirect=True)
+def test_merged_custom_prefetches(db, gql_client: GraphQLTestClient):
+    """Test that duplicated prefetch_related hints are correctly merged."""
+
+    @strawberry_django.type(Issue)
+    class IssueTypeTest:
+        name: strawberry.auto
+        kind: strawberry.auto
+
+    @strawberry_django.type(Milestone)
+    class MilestoneTypeTest:
+        name: strawberry.auto
+
+        @strawberry_django.field()
+        @staticmethod
+        def bugs(parent: strawberry.Parent[Milestone]) -> list[IssueTypeTest]:
+            # This is not the most efficient way to do this, it only exists for this test.
+            return getattr(parent, "bugs", [])
+
+        @strawberry_django.field()
+        @staticmethod
+        def has_bugs(parent: strawberry.Parent[Milestone]) -> bool:
+            # This is not the most efficient way to do this, it only exists for this test.
+            return bool(getattr(parent, "bugs", None))
+
+    @strawberry_django.type(Project)
+    class ProjectTypeTest:
+        name: strawberry.auto
+
+        @staticmethod
+        def _prefetch_custom_milestones(_: GraphQLResolveInfo) -> Prefetch:
+            return Prefetch(
+                "milestones",
+                to_attr="custom_milestones",
+                queryset=Milestone.objects.all().prefetch_related(
+                    Prefetch(
+                        "issues",
+                        Issue.objects.all().filter(kind=Issue.Kind.BUG),
+                        to_attr="bugs",
+                    )
+                ),
+            )
+
+        @strawberry_django.field(prefetch_related=_prefetch_custom_milestones)
+        @staticmethod
+        def milestones(parent: strawberry.Parent[Project]) -> list[MilestoneTypeTest]:
+            return getattr(parent, "custom_milestones", [])
+
+        @strawberry_django.field(prefetch_related=_prefetch_custom_milestones)
+        @staticmethod
+        def milestones2(parent: strawberry.Parent[Project]) -> list[MilestoneTypeTest]:
+            return getattr(parent, "custom_milestones", [])
+
+    @strawberry.type
+    class Query:
+        projects: list[ProjectTypeTest] = strawberry_django.field()
+
+    schema = strawberry.Schema(
+        query=Query,
+        extensions=[DjangoOptimizerExtension],
+    )
+
+    # Create test data
+    project1 = ProjectFactory.create(name="Project1")
+    project2 = ProjectFactory.create(name="Project2")
+    milestone1 = MilestoneFactory.create(project=project1, name="Milestone1")
+    milestone2 = MilestoneFactory.create(project=project1, name="Milestone2")
+    milestone3 = MilestoneFactory.create(project=project2, name="Milestone3")
+    IssueFactory.create(milestone=milestone1, name="TestFeat1M1", kind="f")
+    IssueFactory.create(milestone=milestone1, name="TestBug1M1", kind="b")
+    IssueFactory.create(milestone=milestone1, name="TestFeat2M1", kind="f")
+    IssueFactory.create(milestone=milestone2, name="TestFeat1M2", kind="f")
+    IssueFactory.create(milestone=milestone3, name="TestFeat1M3", kind="f")
+    IssueFactory.create(milestone=milestone3, name="TestBug1M3", kind="b")
+
+    query = """\
+      query TestQuery {
+        projects {
+          name
+          milestones {
+            name
+            hasBugs
+            bugs { name }
+          }
+          milestones2 { name }
+        }
+      }
+    """
+    if DjangoOptimizerExtension.enabled.get():
+        with assert_num_queries(3):
+            result = schema.execute_sync(query)
+    else:
+        result = schema.execute_sync(query)
+
+    assert result.errors is None, result.errors
+    assert result.data == {
+        "projects": [
+            {
+                "name": "Project1",
+                "milestones": [
+                    {
+                        "name": "Milestone1",
+                        "hasBugs": True,
+                        "bugs": [{"name": "TestBug1M1"}],
+                    },
+                    {"name": "Milestone2", "hasBugs": False, "bugs": []},
+                ],
+                "milestones2": [
+                    {"name": "Milestone1"},
+                    {"name": "Milestone2"},
+                ],
+            },
+            {
+                "name": "Project2",
+                "milestones": [
+                    {
+                        "name": "Milestone3",
+                        "hasBugs": True,
+                        "bugs": [{"name": "TestBug1M3"}],
+                    },
+                ],
+                "milestones2": [
+                    {"name": "Milestone3"},
+                ],
+            },
+        ],
+    }
+
+
+@pytest.mark.django_db(transaction=True)
+@pytest.mark.parametrize("gql_client", ["sync"], indirect=True)
+def test_prefetch_with_only_injects_fk_field(db, gql_client: GraphQLTestClient):
+    """FK field is injected into .only() on user-provided Prefetch querysets.
+
+    Regression test for https://github.com/strawberry-graphql/strawberry-django/issues/862
+    """
+
+    @strawberry_django.type(Milestone)
+    class MilestoneTypeTest:
+        name: strawberry.auto
+
+    @strawberry_django.type(Project)
+    class ProjectTypeTest:
+        name: strawberry.auto
+
+        @strawberry_django.field(
+            prefetch_related=[
+                lambda info: Prefetch(
+                    "milestones",
+                    queryset=Milestone.objects.filter(
+                        name__startswith="Test",
+                    ).only("id", "name"),
+                    to_attr="_optimized_milestones",
+                )
+            ]
+        )
+        def optimized_milestones(self) -> list[MilestoneTypeTest]:
+            return self._optimized_milestones  # type: ignore
+
+    @strawberry.type
+    class Query:
+        projects: list[ProjectTypeTest] = strawberry_django.field()
+
+    schema = strawberry.Schema(
+        query=Query,
+        extensions=[DjangoOptimizerExtension],
+    )
+
+    project1 = ProjectFactory.create(name="Project1")
+    project2 = ProjectFactory.create(name="Project2")
+    MilestoneFactory.create(project=project1, name="TestMilestone1")
+    MilestoneFactory.create(project=project1, name="TestMilestone2")
+    MilestoneFactory.create(project=project1, name="OtherMilestone")
+    MilestoneFactory.create(project=project2, name="TestMilestone3")
+
+    query = """\
+      query TestQuery {
+        projects {
+          name
+          optimizedMilestones {
+            name
+          }
+        }
+      }
+    """
+
+    with assert_num_queries(2):
+        result = schema.execute_sync(query)
+
+    assert result.errors is None, result.errors
+    assert result.data is not None
+    projects_data = sorted(result.data["projects"], key=operator.itemgetter("name"))
+    assert len(projects_data) == 2
+    assert projects_data[0]["name"] == "Project1"
+    assert len(projects_data[0]["optimizedMilestones"]) == 2
+    assert projects_data[1]["name"] == "Project2"
+    assert len(projects_data[1]["optimizedMilestones"]) == 1
