@@ -3,7 +3,6 @@ import contextlib
 import contextvars
 import dataclasses
 import inspect
-import warnings
 from typing import (
     Any,
     cast,
@@ -177,7 +176,6 @@ class GraphQLTestClient(TestClient):
         query: str,
         variables: dict[str, Any] | None = None,
         headers: dict[str, object] | None = None,
-        asserts_errors: bool | None = None,
         files: dict[str, object] | None = None,
         assert_no_errors: bool | None = True,
     ) -> Response:
@@ -195,17 +193,7 @@ class GraphQLTestClient(TestClient):
             extensions=data.get("extensions"),
         )
 
-        if asserts_errors is not None:
-            warnings.warn(
-                "The `asserts_errors` argument has been renamed to `assert_no_errors`",
-                DeprecationWarning,
-                stacklevel=2,
-            )
-
-        assert_no_errors = (
-            assert_no_errors if asserts_errors is None else asserts_errors
-        )
         if assert_no_errors:
-            assert response.errors is None
+            assert response.errors is None, response.errors
 
         return response
